#
# spec file for package eventstat
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           eventstat
Version:        0.05.01
Release:        1.1
Summary:        Kernel event states monitoring tool
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://github.com/ColinIanKing/eventstat
Source:         https://github.com/ColinIanKing/eventstat/archive/refs/tags/V%{version}.tar.gz
BuildRequires:  ncurses-devel

%description
Eventstat periodically dumps out the current kernel event state.It keeps track
of current events and outputs the change in events on each output update.
The tool requires sudo to run since it needs to write to /proc/timer_stats to
start and stop the event monitoring.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Benchmark
BuildRequires:  bash-completion
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (eventstat and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for %{name}.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
%make_build

%install
%make_install

%files
%license COPYING
%doc README.md
%{_bindir}/eventstat
%{_mandir}/man8/eventstat.8%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Fri Mar 17 2023 Dirk Müller <dmueller@suse.com>
- update to 0.05.01:
  * Minor code cleanup, no functional changes
  * Fix potential division by zero when duration is 0.0
  * Limit sscanf string field sizes to match size of buffers
    being used
* Thu Apr 28 2022 Dirk Müller <dmueller@suse.com>
- udpate to 0.04.13:
  * manual: update date, author email and copyright
  * Add README.md file
  * snapcraft: update to core20
* Thu Apr 29 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.04.12
  * Rename clock_tick_rate to g_clock_tick_rate
  * Make get_events_buf local
- Update to version 0.04.11
  * handle case where comm field contains ) and spaces
* Sat Nov  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.04.10
  * handle case where comm field contains ) and spaces
* Mon Mar  9 2020 Martin Hauke <mardnh@gmx.de>
- Drop SLE12 compat ifdef
- Supplement against bash-completion, not bash
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.04.09
  * Add bash completion script
* Tue Dec 17 2019 Martin Hauke <mardnh@gmx.de>
- update to version 0.04.08
  * Add UNLIKELY hinting on memory allocation failure checks
  * check for failed allocation of comm field
  * Add null check on failed allocation of comm field
  * Add null check on return of ctime
  * Don't strdup basename return but strdup base string
  * Fix inverted null check logic on comm field
  * Add null check on localtime return
  * check that basename returns a non-null string
  * fix out of memory allocation failure check
  * eventstat: fix '\n' check on string (null ptr dereference)
  * eventstat: use comm field for task name rather than task info
    field
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.04.07
  * No functional changes
* Fri Jul 12 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.04.06
  * Reduce scope of variable ticks
  * Remove unused assignments
  * Update copyright year
* Sat Jan 12 2019 mardnh@gmx.de
- Update to version 0.04.05
  * Add in some missing voidifications on function returns
  * Make task_mangled large enough to avoid truncation
  * Re-order some fields in timer_info to pack more efficiently
* Thu Jun 14 2018 mardnh@gmx.de
- Update to version 0.04.04
  * Makefile: bump version
  * debian/copyright: use secure url https:// etc
  * debian/control: remove trailing empty line
  * Fix -b brief mode headings
  * Ensure we have at least 1 task accounted for
  * Add CPU load, real time priority and niceness fields
  * Add fast check if we are inside a container
- Fix version number typos in changelog
* Thu Feb  1 2018 mardnh@gmx.de
- Update to version 0.04.03
  * Makefile: bump version
  * re-format some overly wide source lines
  * Don't force wide display unless long mode is used
  * eventstat: add some more UNLIKELY/LIKELY annotations
  * Update copyright dates
* Thu Oct 19 2017 mardnh@gmx.de
- Update to version 0.04.02
  * Makefile: bump version
  * Iterate over arrays using size of array rather than using
    sentinels at end of array
  * Remove empty lines
  * Voidify returns from various functions
  * Add some UNLIKELY/LIKELY branch hinting
  * debian/control: update Standards-Version to 4.1.1
  * Prefix all globals with g_ to notify scope
  * Use sizeof object rather than size of type
  * Remove whitespace from source
* Sat Aug 19 2017 mardnh@gmx.de
- Update to version 0.04.01
  * Makefile: bump version
  * Remove unused variable fields
  * Fix -c cumulative stats
  * Make column sizing more intelligent
  * snapcraft: Makefile: set LC_ALL=C.UTF-8 LANG=C.UTF-8
  * Add back ref_count reference counting which was accidentally removed
  * Compute column width correctly with -i mode being used
  * Make source more 80 column friendly
  * Use double_to_timeval instead of time coversion
  * Minor code clean up, no functional changes
  * Fix non-root failure message
  * Break out of trace reading loop on SIGINT
  * Add -i timer ID information mode
  * Add libncurses5-dev to snapcraft build dependencies
- Update to version 0.04.00
  * Makefile: bump version
  * Debian/control: update Standards-Version to 4.0.0
  * Update manual
  * Fix reversed order sample list, put data on tail instead of head
  * Add back functioning -S option now that stats look sane
  * Fake initial previous time event on first event.
  * Remove whence debug info
  * Eventstat: use event tracing rather than the older deprecated
    /proc/timer_stats interface (LP: #1705472)
  * Make symlink to snapcraft file
  * Snapcraft: add default type and grade keys to yaml
* Wed May 10 2017 mardnh@gmx.de
- update to version 0.03.04
  * Makefile: bump version
  * Add GNU C printf attribute to err_abort
  * Makefile: add snapcraft files to make dist rule
  * Add variable pid size handling.
  * Add snapcraft files
  * Update copyright year
  * Fix non-ANSI declaration of functions eventstat_winsize
    and eventstat_refresh
- update to version 0.03.03
  * Makefile: bump version
  * Fix FLOAT_CMP macro - need fabs on result
  * Remove sdl declarations to fix sdl shadowing
  * constify info1, info2
  * Move scope of duration, removes shadowing of this variable
  * Allow floating point comparisons a little bit of tiny slop
  * Add stdarg.h header
  * use gnu printf style attributes for es_printf
  * Makefile: add PEDANTIC flags
* Sat Jul 30 2016 mardnh@gmx.de
- update to version 0.03.02
  * Makefile: bump version
  * debian/control: update Standards-Version to 3.9.8
* Thu Feb 18 2016 mardnh@gmx.de
- update to version 0.03.01
  * Makefile: bump version
  * Update manual to reflect -l -s mode on tty output
  * Show long or short command line info in tty output and not just in CSV
  * Add smart column resizing based on variable tty width
  * Add some small ncurses helpers for top only mode
  * Clean up -h info, make it 80 column friendly
  * Remove a few empty lines in source
  * Re-align global vars so there is less wasted padding
  * Make source 80 column friendly
  * es_printf: emit curses output if curses_init is true
  * Reformat overly long function declarations
  * Minor code improvement in set_timer_stat
  * check for failed sigaction on SIGWINCH
  * Improve error handling with some error message and clean up helpers
  * Call endwin() only in top mode
* Wed Nov 11 2015 mardnh@gmx.de
- initial package
